==> MMDX-v1.50a-src.zip: MMDX-v1.50a-src/MMDImporter/Accessory/VACImporter.cs <==
using System;
using System.IO;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content.Pipeline;
using TImport = MikuMikuDance.XNA.Accessory.MMD_VAC;

namespace MikuMikuDance.XNA.Accessory
{
    /// <summary>
    /// MikuMikuDance.vacݒt@CC|[g邽߂̃Cu
    /// </summary>
    [ContentImporter(".vac", DisplayName = "MikuMikuDance VAC : MikuMikuDance for XNA", CacheImportedData = true, DefaultProcessor = "")]
    public class VACImporter : ContentImporter<TImport>
    {
        /// <summary>
        /// C|[g
        /// </summary>
        /// <param name="filename">t@C</param>
        /// <param name="context">RegC|[^</param>
        /// <returns>VACf[^</returns>
        /// <remarks>XNÃC|[^Ăяo</remarks>
        public override TImport Import(string filename, ContentImporterContext context)
        {
            float scale;
            Vector3 move, rot;
            string bone;
            bool shadow = false;
            using (StreamReader sr = new StreamReader(filename, Encoding.GetEncoding(932)))
            {
                //ANZTxt@C͓ǂ܂Ȃ
                sr.ReadLine();
                sr.ReadLine();
                //g嗦
                scale = Convert.ToSingle(sr.ReadLine());
                //ʒu
                string[] data = sr.ReadLine().Split(',');
                move = new Vector3(Convert.ToSingle(data[0]), Convert.ToSingle(data[1]), Convert.ToSingle(data[2]));
                //]
                data = sr.ReadLine().Split(',');
                rot = new Vector3(Convert.ToSingle(data[0]), Convert.ToSingle(data[1]), Convert.ToSingle(data[2]));
                //{[
                bone = sr.ReadLine();
                int num;
                if (int.TryParse(sr.ReadLine().Trim(), out num))
                    shadow = (num != 0);
                sr.Close();

            }
            return new TImport()
            {
                BoneName = bone,
                Shadow = shadow,
                Transform = Matrix.CreateScale(scale) * Matrix.CreateFromYawPitchRoll(rot.Y, rot.X, rot.Z) * Matrix.CreateTranslation(move)
            };
        }
    }
}

==> MMDX-v1.53a-src.zip: MMDX-v1.53a-src/MMDImporter/Accessory/VACImporter.cs <==
using System;
using System.IO;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content.Pipeline;
using TImport = MikuMikuDance.XNA.Accessory.VACContent;

namespace MikuMikuDance.XNA.Accessory
{
    /// <summary>
    /// MikuMikuDance.vacݒt@CC|[g邽߂̃Cu
    /// </summary>
    [ContentImporter(".vac", DisplayName = "MikuMikuDance VAC : MikuMikuDance for XNA", CacheImportedData = true, DefaultProcessor = "VACProcessor")]
    public class VACImporter : ContentImporter<TImport>
    {
        /// <summary>
        /// C|[g
        /// </summary>
        /// <param name="filename">t@C</param>
        /// <param name="context">RegC|[^</param>
        /// <returns>VACf[^</returns>
        /// <remarks>XNÃC|[^Ăяo</remarks>
        public override TImport Import(string filename, ContentImporterContext context)
        {
            float scale;
            Vector3 move, rot;
            string bone;
            bool shadow = false;
            using (StreamReader sr = new StreamReader(filename, Encoding.GetEncoding(932)))
            {
                //ANZTxt@C͓ǂ܂Ȃ
                sr.ReadLine();
                sr.ReadLine();
                //g嗦
                scale = Convert.ToSingle(sr.ReadLine());
                //ʒu
                string[] data = sr.ReadLine().Split(',');
                move = new Vector3(Convert.ToSingle(data[0]), Convert.ToSingle(data[1]), Convert.ToSingle(data[2]));
                //]
                data = sr.ReadLine().Split(',');
                rot = new Vector3(
                    MathHelper.ToRadians(Convert.ToSingle(data[0])),
                    MathHelper.ToRadians(Convert.ToSingle(data[1])),
                    MathHelper.ToRadians(Convert.ToSingle(data[2])));
                //{[
                bone = sr.ReadLine();
                int num;
                if (int.TryParse(sr.ReadLine().Trim(), out num))
                    shadow = (num != 0);
                sr.Close();

            }
            return new TImport()
            {
                BoneName = bone,
                Shadow = shadow,
                Scale = scale,
                Rot = rot,
                Trans = move
            };
        }
    }
}
